==> i-want-it-earlier-4.1.0-sources.jar: rs/onako2/iwie/IWantItEarlier.java <==
package rs.onako2.iwie;

import net.fabricmc.api.ModInitializer;
import net.fabricmc.fabric.api.itemgroup.v1.FabricItemGroup;
import net.fabricmc.fabric.api.object.builder.v1.entity.FabricDefaultAttributeRegistry;
import net.minecraft.class_1291;
import net.minecraft.class_1299;
import net.minecraft.class_1311;
import net.minecraft.class_1761;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1826;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2378;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_4970;
import net.minecraft.class_5321;
import net.minecraft.class_6880;
import net.minecraft.class_7923;
import net.minecraft.class_7924;
import net.minecraft.class_9886;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import rs.onako2.iwie.effect.BreathOfTheNautilusEffect;
import rs.onako2.iwie.entity.AbstractNautilusEntity;
import rs.onako2.iwie.entity.NautilusEntity;
import rs.onako2.iwie.entity.ZombieNautilusEntity;
import rs.onako2.iwie.item.SpearItem;

public class IWantItEarlier implements ModInitializer {
    public static final String MOD_ID = "iwie";
    public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);

    public static final class_1299<NautilusEntity> NAUTILUS_ENTITY = class_2378.method_10230(
            class_7923.field_41177,
            Identifiers.NAUTILUS_ID,
            class_1299.class_1300.method_5903(NautilusEntity::new, class_1311.field_6302)
                    .method_17687(1.0F, 1.15F)
                    .method_55687(0.4F)
                    .method_27299(24)
                    .method_19947()
                    .method_63006()
                    .method_5905(class_5321.method_29179(class_7924.field_41266, Identifiers.NAUTILUS_ID))
    );

    public static final class_1299<ZombieNautilusEntity> ZOMBIE_NAUTILUS_ENTITY = class_2378.method_10230(
            class_7923.field_41177,
            Identifiers.ZOMBIE_NAUTILUS_ID,
            class_1299.class_1300.method_5903(ZombieNautilusEntity::new, class_1311.field_6302)
                    .method_17687(1.0F, 1.15F)
                    .method_55687(0.4F)
                    .method_27299(24)
                    .method_19947()
                    .method_63006()
                    .method_5905(class_5321.method_29179(class_7924.field_41266, Identifiers.ZOMBIE_NAUTILUS_ID))
    );

    public static final class_2248 TEST = class_2246.method_63052(class_5321.method_29179(class_7924.field_41254, Identifiers.TEST_ID), class_4970.class_2251.method_9637().method_9632(4.0f));

    public static final class_1792 NAUTILUS_SPAWN_EGG = class_1802.method_63747(class_5321.method_29179(class_7924.field_41197, Identifiers.NAUTILUS_SPAWN_EGG), settings -> new class_1826(NAUTILUS_ENTITY, settings));
    public static final class_1792 ZOMBIE_NAUTILUS_SPAWN_EGG = class_1802.method_63747(class_5321.method_29179(class_7924.field_41197, Identifiers.ZOMBIE_NAUTILUS_SPAWN_EGG), settings -> new class_1826(ZOMBIE_NAUTILUS_ENTITY, settings));

    public static final class_1792 WOODEN_SPEAR = class_1802.method_63747(class_5321.method_29179(class_7924.field_41197, Identifiers.WOODEN_SPEAR_ID), settings -> new SpearItem(settings.method_66333(class_9886.field_52585, 7.0F, -2.4F).method_62832(2.0f)));
    public static final class_1792 STONE_SPEAR = class_1802.method_63747(class_5321.method_29179(class_7924.field_41197, Identifiers.STONE_SPEAR_ID), settings -> new SpearItem(settings.method_66333(class_9886.field_52586, 7.0F, -2.4F).method_62832(2.0f)));
    public static final class_1792 COPPER_SPEAR = class_1802.method_63747(class_5321.method_29179(class_7924.field_41197, Identifiers.COPPER_SPEAR_ID), settings -> new SpearItem(settings.method_66333(class_9886.field_52587, 7.0F, -2.4F).method_62832(2.0f)));
    public static final class_1792 IRON_SPEAR = class_1802.method_63747(class_5321.method_29179(class_7924.field_41197, Identifiers.IRON_SPEAR_ID), settings -> new SpearItem(settings.method_66333(class_9886.field_52587, 7.0F, -2.4F).method_62832(2.0f)));
    public static final class_1792 GOLDEN_SPEAR = class_1802.method_63747(class_5321.method_29179(class_7924.field_41197, Identifiers.GOLDEN_SPEAR_ID), settings -> new SpearItem(settings.method_66333(class_9886.field_52589, 7.0F, -2.4F).method_62832(2.0f)));
    public static final class_1792 DIAMOND_SPEAR = class_1802.method_63747(class_5321.method_29179(class_7924.field_41197, Identifiers.DIAMOND_SPEAR_ID), settings -> new SpearItem(settings.method_66333(class_9886.field_52588, 7.0F, -2.4F).method_62832(2.0f)));
    public static final class_1792 NETHERITE_SPEAR = class_1802.method_63747(class_5321.method_29179(class_7924.field_41197, Identifiers.NETHERITE_SPEAR_ID), settings -> new SpearItem(settings.method_66333(class_9886.field_52590, 7.0F, -2.4F).method_24359().method_62832(2.0f)));

    private static final class_1761 IWIE = FabricItemGroup.builder()
            .method_47320(() -> new class_1799(NAUTILUS_SPAWN_EGG))
            .method_47321(class_2561.method_43471("itemGroup.iwie.main"))
            .method_47317((context, entries) -> {
                entries.method_45421(NAUTILUS_SPAWN_EGG);
                entries.method_45421(ZOMBIE_NAUTILUS_SPAWN_EGG);
                entries.method_45421(WOODEN_SPEAR);
                entries.method_45421(STONE_SPEAR);
                entries.method_45421(COPPER_SPEAR);
                entries.method_45421(IRON_SPEAR);
                entries.method_45421(GOLDEN_SPEAR);
                entries.method_45421(DIAMOND_SPEAR);
                entries.method_45421(NETHERITE_SPEAR);
            })
            .method_47324();

    public static final class_6880<class_1291> BREATH_OF_NAUTILUS = class_2378.method_47985(class_7923.field_41174, Identifiers.BREATH_OF_THE_NAUTILUS_ID, new BreathOfTheNautilusEffect());

    @Override
    public void onInitialize() {

        LOGGER.info("Initializing items and blocks from next update!");

        class_2378.method_10230(class_7923.field_44687, class_2960.method_60655(MOD_ID, "main"), IWIE);

        ModRegistry.registerItems();

        FabricDefaultAttributeRegistry.register(NAUTILUS_ENTITY, AbstractNautilusEntity.createAbstractNautilusAttributes());
        FabricDefaultAttributeRegistry.register(ZOMBIE_NAUTILUS_ENTITY, AbstractNautilusEntity.createAbstractNautilusAttributes());
    }
}

==> i-want-it-earlier-4.4.0-sources.jar: rs/onako2/iwie/IWantItEarlier.java <==
package rs.onako2.iwie;

import net.fabricmc.api.ModInitializer;
import net.fabricmc.fabric.api.biome.v1.BiomeModifications;
import net.fabricmc.fabric.api.biome.v1.BiomeSelectors;
import net.fabricmc.fabric.api.itemgroup.v1.FabricItemGroup;
import net.fabricmc.fabric.api.object.builder.v1.entity.FabricDefaultAttributeRegistry;
import net.minecraft.class_1291;
import net.minecraft.class_1299;
import net.minecraft.class_1311;
import net.minecraft.class_1761;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1826;
import net.minecraft.class_1972;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2378;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_4970;
import net.minecraft.class_5321;
import net.minecraft.class_6880;
import net.minecraft.class_7923;
import net.minecraft.class_7924;
import net.minecraft.class_9886;
import org.jetbrains.annotations.NotNull;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import rs.onako2.iwie.effect.BreathOfTheNautilusEffect;
import rs.onako2.iwie.entity.AbstractNautilusEntity;
import rs.onako2.iwie.entity.NautilusEntity;
import rs.onako2.iwie.entity.ZombieNautilusEntity;
import rs.onako2.iwie.item.SpearItem;

public class IWantItEarlier implements ModInitializer {
    public static final String MOD_ID = "iwie";
    public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);

    @NotNull
    public static final class_1299<NautilusEntity> NAUTILUS_ENTITY = class_2378.method_10230(
            class_7923.field_41177,
            Identifiers.NAUTILUS_ID,
            class_1299.class_1300.method_5903(NautilusEntity::new, class_1311.field_6302)
                    .method_17687(1.0F, 1.15F)
                    .method_55687(0.4F)
                    .method_27299(24)
                    .method_19947()
                    .method_63006()
                    .method_5905(class_5321.method_29179(class_7924.field_41266, Identifiers.NAUTILUS_ID))
    );

    @NotNull
    public static final class_1299<ZombieNautilusEntity> ZOMBIE_NAUTILUS_ENTITY = class_2378.method_10230(
            class_7923.field_41177,
            Identifiers.ZOMBIE_NAUTILUS_ID,
            class_1299.class_1300.method_5903(ZombieNautilusEntity::new, class_1311.field_6302)
                    .method_17687(1.0F, 1.15F)
                    .method_55687(0.4F)
                    .method_27299(24)
                    .method_19947()
                    .method_63006()
                    .method_5905(class_5321.method_29179(class_7924.field_41266, Identifiers.ZOMBIE_NAUTILUS_ID))
    );

    public static final class_2248 TEST = class_2246.method_63052(class_5321.method_29179(class_7924.field_41254, Identifiers.TEST_ID), class_4970.class_2251.method_9637().method_9632(4.0f));

    public static final class_1792 NAUTILUS_SPAWN_EGG = class_1802.method_63747(class_5321.method_29179(class_7924.field_41197, Identifiers.NAUTILUS_SPAWN_EGG), settings -> new class_1826(NAUTILUS_ENTITY, settings));
    public static final class_1792 ZOMBIE_NAUTILUS_SPAWN_EGG = class_1802.method_63747(class_5321.method_29179(class_7924.field_41197, Identifiers.ZOMBIE_NAUTILUS_SPAWN_EGG), settings -> new class_1826(ZOMBIE_NAUTILUS_ENTITY, settings));

    public static final class_1792 WOODEN_SPEAR = class_1802.method_63747(class_5321.method_29179(class_7924.field_41197, Identifiers.WOODEN_SPEAR_ID), settings -> new SpearItem(settings.method_66333(class_9886.field_52585, 7.0F, -2.4F).method_62832(2.0f)));
    public static final class_1792 STONE_SPEAR = class_1802.method_63747(class_5321.method_29179(class_7924.field_41197, Identifiers.STONE_SPEAR_ID), settings -> new SpearItem(settings.method_66333(class_9886.field_52586, 7.0F, -2.4F).method_62832(2.0f)));
    public static final class_1792 COPPER_SPEAR = class_1802.method_63747(class_5321.method_29179(class_7924.field_41197, Identifiers.COPPER_SPEAR_ID), settings -> new SpearItem(settings.method_66333(class_9886.field_52587, 7.0F, -2.4F).method_62832(2.0f)));
    public static final class_1792 IRON_SPEAR = class_1802.method_63747(class_5321.method_29179(class_7924.field_41197, Identifiers.IRON_SPEAR_ID), settings -> new SpearItem(settings.method_66333(class_9886.field_52587, 7.0F, -2.4F).method_62832(2.0f)));
    public static final class_1792 GOLDEN_SPEAR = class_1802.method_63747(class_5321.method_29179(class_7924.field_41197, Identifiers.GOLDEN_SPEAR_ID), settings -> new SpearItem(settings.method_66333(class_9886.field_52589, 7.0F, -2.4F).method_62832(2.0f)));
    public static final class_1792 DIAMOND_SPEAR = class_1802.method_63747(class_5321.method_29179(class_7924.field_41197, Identifiers.DIAMOND_SPEAR_ID), settings -> new SpearItem(settings.method_66333(class_9886.field_52588, 7.0F, -2.4F).method_62832(2.0f)));
    public static final class_1792 NETHERITE_SPEAR = class_1802.method_63747(class_5321.method_29179(class_7924.field_41197, Identifiers.NETHERITE_SPEAR_ID), settings -> new SpearItem(settings.method_66333(class_9886.field_52590, 7.0F, -2.4F).method_24359().method_62832(2.0f)));

    private static final class_1761 IWIE = FabricItemGroup.builder()
            .method_47320(() -> new class_1799(NAUTILUS_SPAWN_EGG))
            .method_47321(class_2561.method_43471("itemGroup.iwie.main"))
            .method_47317((context, entries) -> {
                entries.method_45421(NAUTILUS_SPAWN_EGG);
                entries.method_45421(ZOMBIE_NAUTILUS_SPAWN_EGG);
                entries.method_45421(WOODEN_SPEAR);
                entries.method_45421(STONE_SPEAR);
                entries.method_45421(COPPER_SPEAR);
                entries.method_45421(IRON_SPEAR);
                entries.method_45421(GOLDEN_SPEAR);
                entries.method_45421(DIAMOND_SPEAR);
                entries.method_45421(NETHERITE_SPEAR);
            })
            .method_47324();

    public static final class_6880<class_1291> BREATH_OF_NAUTILUS = class_2378.method_47985(class_7923.field_41174, Identifiers.BREATH_OF_THE_NAUTILUS_ID, new BreathOfTheNautilusEffect());

    @Override
    public void onInitialize() {

        LOGGER.info("Initializing items and blocks from next update!");

        class_2378.method_10230(class_7923.field_44687, class_2960.method_60655(MOD_ID, "main"), IWIE);

        ModRegistry.registerItems();

        FabricDefaultAttributeRegistry.register(NAUTILUS_ENTITY, AbstractNautilusEntity.createAbstractNautilusAttributes());
        FabricDefaultAttributeRegistry.register(ZOMBIE_NAUTILUS_ENTITY, AbstractNautilusEntity.createAbstractNautilusAttributes());

        BiomeModifications.addSpawn(BiomeSelectors.includeByKey(class_1972.field_9451, class_1972.field_9449), class_1311.field_6302, class_1299.field_6048, 1, 1, 1);
        BiomeModifications.addSpawn(BiomeSelectors.includeByKey(class_1972.field_9423, class_1972.field_9467, class_1972.field_9470, class_1972.field_9446, class_1972.field_9418, class_1972.field_9439, class_1972.field_9408, class_1972.field_9435), class_1311.field_30092, NAUTILUS_ENTITY, 1, 1, 2);
    }
}
